@@ -1,10 +1,10 @@
 package CPAN::Packager::Builder::Deb;
 use Mouse;
 use Carp;
-use IPC::System::Simple qw(system);
 use Path::Class;
 use List::MoreUtils qw(any);
 use CPAN::Packager::Home;
+use CPAN::Packager::Util;
 with 'CPAN::Packager::Builder::Role';
 with 'CPAN::Packager::Role::Logger';
 
@@ -23,19 +23,23 @@ sub BUILD {
 }
 
 sub check_executables_exist_in_path {
-    system("which dh-make-perl");
-    system("which dpkg");
+    die "dh_make_perl doesn't exist in PATH"
+        if CPAN::Packager::Util::run_command("which dh-make-perl");
+    die "dpkg doesn't exist in PATH"
+        if CPAN::Packager::Util::run_command("which dpkg");
 }
 
 sub build {
     my ( $self, $module ) = @_;
-    $self->_build_package_with_dh_make_perl($module);
+    my $package = $self->_build_package_with_dh_make_perl($module);
+    $self->install($module);
+    return $package;
 }
 
 sub _build_package_with_dh_make_perl {
     my ( $self, $module ) = @_;
     die "module param must have module name" unless $module->{module};
-    die "Can't find source for package" unless $module->{src};
+    die "Can't find source for package"      unless $module->{src};
 
     my $package            = $self->package_name( $module->{module} );
     my $package_output_dir = $self->package_output_dir;
@@ -46,13 +50,16 @@ sub _build_package_with_dh_make_perl {
         }
     }
 
+    my $verbose = $self->config( global => "verbose" );
     eval {
-        system("rm -rf $module->{src}/debian");
+        CPAN::Packager::Util::run_command( "rm -rf $module->{src}/debian",
+            $verbose );
         my $dh_make_perl_cmd
             = $self->_build_dh_make_perl_command( $module, $package );
-        system($dh_make_perl_cmd);
-        system("sudo dpkg -i $module->{src}/../$package*.deb");
-        system("sudo cp $module->{src}/../$package*.deb $package_output_dir");
+        CPAN::Packager::Util::run_command( $dh_make_perl_cmd, $verbose );
+        CPAN::Packager::Util::run_command(
+            "cp $module->{src}/../$package*.deb $package_output_dir",
+            $verbose );
 
     };
     if ($@) {
@@ -62,31 +69,43 @@ sub _build_package_with_dh_make_perl {
     $package;
 }
 
+sub install {
+    my ( $self, $module ) = @_;
+    my $package = $self->package_name( $module->{module} );
+    CPAN::Packager::Util::run_command(
+        "sudo dpkg -i $module->{src}/../${package}_@{[ $module->{version} ]}*.deb",
+        $self->config( global => "verbose" )
+    );
+
+}
+
 sub _build_dh_make_perl_command {
     my ( $self, $module, $package ) = @_;
     my @depends = $self->depends($module);
     my $depends = join ',', @depends;
     $self->log( debug => "depends: $depends" );
     my $dh_make_perl_cmd
-    # = "dh-make-perl --build --depends '$depends' $module->{src} --package $package "; # hmm. etch's dh-make-perl don't have --package option.
-        = "dh-make-perl --build --depends '$depends' $module->{src}";
+
+# = "dh-make-perl --build --depends '\${shlibs:Depends},$depends' $module->{src} --package $package "; # hmm. etch's dh-make-perl don't have --package option.
+        = "dh-make-perl --build --depends '\${shlibs:Depends},$depends' $module->{src}";
     if ( $module->{skip_test} ) {
         $dh_make_perl_cmd .= " --notest";
     }
     if ( $module->{version} ) {
         my $version = $module->{version};
+
         # XXX: Debian package compare version.
-        # So if module version is 1.2 and debian's module version is 1.1901, 
+        # So if module version is 1.2 and debian's module version is 1.1901,
         # atitude install 1.1901.
         # so convert vertion 1.2 to 1.2000.
-        if ( $version =~ /^(\d+\.)(\d)+$/ ) { # major-minor pattern version.
+        if ( $version =~ /^(\d+\.)(\d)+$/ ) {   # major-minor pattern version.
             my $geta = length $1;
             while ( length($version) - $geta < 4 ) {
                 $version .= "0";
             }
         }
-        
-        $version .= "-1";
+
+        $version          .= "-1";
         $dh_make_perl_cmd .= " --version $version";
     }
 
